# Why TOF-SIMS ?
We needed a convenient way to explore the 3D datasets generated by a TESCAN FERA Xe plasma FIB-SEM with ToF-SIMS.  This package expands on the functions provided by the manufacturer.


# Highlights
## Machine learning
* Multivariate analysis with PCA, kPCA, IPCA
* t-SNE clustering
* Machine learning (KMeans)
* Detailed cluster analysis


## Plots
Available functions so far:
* Read data from TOF-SIMS (.HDF5) files, making the data directly accessible in Python (numpy/pandas/matplotlib).
* Generate top, sides projections, visualise surface before FIB-ing
* Plot detected masses
* Maximal projections for any given axis (x,y,z) and every isotopes/masses (useful to have a quick look at detected species).
* Inspect top, side and depth projections for a given isotope/mass
* Plot (and superpose) the abundance of species over any axis.
* Overlays maximal projections.
* Read in the complete file header. Get access to every setting of the machine recorded at the time of the experiment.
* Export plots.
* 3D interactive plot


# Instructions
Code in TOF-SIMS Notebook.ipynb should be self-explanatory.  If needed feel free to contact us at remi.branco@hotmail.fr or daniel.thomas.oldfield@gmail.com
Help and feedback is very welcome.


# What's next
* More machine learning (DB-scan)
* Better 3D plots (open3D)
* Data reprocessing/peak-refining
* Peak identification
* Denoising with neural network
